..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _introduction:

What is Invenio?
================

.. todo::

   Fix up this section

Features
--------

Navigable collection tree
~~~~~~~~~~~~~~~~~~~~~~~~~

.. image:: /_static/snap1.gif
   :width: 200 px
   :align: left

* Documents organised in collections
* Regular and virtual collection trees
* Customizable portalboxes for each collection
* At CERN, over 1,000,000 documents in 700 collections

.. raw:: html

  <br clear="all" />

Powerful search engine
~~~~~~~~~~~~~~~~~~~~~~

.. image:: /_static/snap2.gif
   :width: 200 px
   :align: left

* Specially designed indexes to provide fast search speed for repositories of up to 2,000,000 records
* Customizable simple and advanced search interfaces
* Combined metadata, fulltext and citation search in one go
* Results clustering by collection

.. raw:: html

  <br clear="all" />

Flexible metadata
~~~~~~~~~~~~~~~~~

.. image:: /_static/snap3.gif
   :width: 200 px
   :align: left

* Standard metadata format (MARC)
* Handling articles, books, theses, photos, videos, museum objects and more
* Customizable display and linking rules

.. raw:: html

  <br clear="all" />

User personalization
~~~~~~~~~~~~~~~~~~~~

.. image:: /_static/snap4.gif
   :width: 200 px
   :align: left

* user-defined document baskets
* user-defined automated email notification alerts
* basket-sharing within user groups
* Amazon-like user comments for documents in repository and shared baskets

.. raw:: html

  <br clear="all" />

Multiple output formats
~~~~~~~~~~~~~~~~~~~~~~~

.. image:: /_static/invenio_formats.jpg
   :width: 200 px
   :align: left

.. raw:: html

  <br clear="all" />


Who is using Invenio?
=====================
.. todo::

   Write this section
